@@ -56,6 +56,35 @@ module TestIRB
       assert_include output, "=> 12"
     end
 
+    def test_local_variable_handeld_correctly
+      write_ruby <<~'RUBY'
+        tap do |if:0, and:0, foo:100|
+          binding.irb
+        end
+      RUBY
+
+      output = run_ruby_file do
+        type 'foo /4#/ do'
+        type 'exit!'
+      end
+      assert_include output, '=> 25'
+    end
+
+    def test_commands_dont_override_stored_last_result
+      write_ruby <<~'RUBY'
+        binding.irb
+      RUBY
+
+      output = run_ruby_file do
+        type "1 + 1"
+        type "ls"
+        type "_ + 10"
+        type "exit!"
+      end
+
+      assert_include output, "=> 12"
+    end
+
     def test_evaluate_with_encoding_error_without_lineno
       if RUBY_ENGINE == 'truffleruby'
         omit "Remove me after https://github.com/ruby/prism/issues/2129 is addressed and adopted in TruffleRuby"
@@ -140,8 +169,8 @@ module TestIRB
         type 'exit'
       end
 
-      assert_include output, '{:context_changed=>true}'
-      assert_include output, '{:context_restored=>true}'
+      assert_include output, {context_changed: true}.inspect
+      assert_include output, {context_restored: true}.inspect
     end
   end
 
@@ -511,9 +540,6 @@ module TestIRB
       end
 
       def test_heredoc_with_indent
-        if Gem::Version.new(RUBY_VERSION) < Gem::Version.new('2.7.0')
-          pend 'This test needs Ripper::Lexer#scan to take broken tokens'
-        end
         input_with_correct_indents = [
           [%q(<<~Q+<<~R), 0, 2, 1],
           [%q(a), 2, 2, 1],
@@ -851,9 +877,16 @@ module TestIRB
       end
 
       assert_match(/irbtest-.*\.rb:2:in (`|'Object#)foo': error \(RuntimeError\)/, output)
-      frame_traces = output.split("\n").select { |line| line.strip.match?(/from /) }.map(&:strip)
+      frame_traces = output.split("\n").map(&:strip).grep(/from /)
 
-      expected_traces = if RUBY_VERSION >= "3.3.0"
+      expected_traces = if RUBY_VERSION >= "3.5.0"
+        [
+          /from .*\/irbtest-.*.rb:6:in (`|'Object#)bar'/,
+          /from .*\/irbtest-.*.rb\(irb\):1:in [`']<main>'/,
+          /from .*\/irbtest-.*.rb:9:in (`|'Binding#)irb'/,
+          /from .*\/irbtest-.*.rb:9:in [`']<main>'/
+        ]
+      elsif RUBY_VERSION >= "3.3.0"
         [
           /from .*\/irbtest-.*.rb:6:in (`|'Object#)bar'/,
           /from .*\/irbtest-.*.rb\(irb\):1:in [`']<main>'/,
@@ -906,13 +939,22 @@ module TestIRB
       end
 
       assert_match(/irbtest-.*\.rb:2:in (`|'Object#)foo': error \(RuntimeError\)/, output)
-      frame_traces = output.split("\n").select { |line| line.strip.match?(/from /) }.map(&:strip)
+      frame_traces = output.split("\n").map(&:strip).grep(/from /)
 
-      expected_traces = [
-        /from .*\/irbtest-.*.rb:6:in (`|'Object#)bar'/,
-        /from .*\/irbtest-.*.rb\(irb\):1:in [`']<main>'/,
-        /from .*\/irbtest-.*.rb:9:in [`']<main>'/
-      ]
+      expected_traces = if RUBY_VERSION >= "3.5.0"
+        [
+          /from .*\/irbtest-.*.rb:6:in (`|'Object#)bar'/,
+          /from .*\/irbtest-.*.rb\(irb\):1:in [`']<main>'/,
+          /from .*\/irbtest-.*.rb:9:in (`|'Binding#)irb'/,
+          /from .*\/irbtest-.*.rb:9:in [`']<main>'/
+        ]
+      else
+        [
+          /from .*\/irbtest-.*.rb:6:in (`|'Object#)bar'/,
+          /from .*\/irbtest-.*.rb\(irb\):1:in [`']<main>'/,
+          /from .*\/irbtest-.*.rb:9:in [`']<main>'/
+        ]
+      end
 
       expected_traces.reverse! if RUBY_VERSION < "3.0.0"
 
